This is used in various places when converting agentMatrix objects to
SpatialPoints for use with functions, such as buffer.
None of these functions results in any real geospatial information being conserved,
other than distance and angle calculations. Buffering still occurs on the
unit-less World. This is therefore a way to allow sp and raster
functions to work as if a cell in the World was equal to 1 m. The resulting
answers will be converted back to units of "cells", not "m".
The CRS() operation is relatively time consuming.
Having a single object usable throughout is much faster.
.projNowhereAn object of class CRS of length 1.